Engine Reference
================

.. include:: shared/engine_table.rst

Base
----
.. autoclass:: kani.engines.base.BaseEngine
    :members:

.. autoclass:: kani.engines.base.BaseCompletion
    :members:

.. autoclass:: kani.engines.base.Completion
    :members:

.. autoclass:: kani.engines.httpclient.BaseClient
    :members:

OpenAI
------
.. autoclass:: kani.engines.openai.OpenAIEngine

.. autoclass:: kani.engines.openai.client.OpenAIClient
    :members:

Hugging Face
------------
.. autoclass:: kani.engines.huggingface.base.HuggingEngine
    :members:

.. autoclass:: kani.engines.huggingface.llama2.LlamaEngine
    :members:

.. autoclass:: kani.engines.huggingface.vicuna.VicunaEngine
    :members:

CTransformers
-------------
.. autoclass:: kani.engines.ctransformers.base.CTransformersEngine
    :members:

.. autoclass:: kani.engines.ctransformers.llama2.LlamaCTransformersEngine
    :members:
